@@ -18,7 +18,6 @@
 import warnings
 
 from ai.h2o.sparkling.SharedBackendConfUtils import SharedBackendConfUtils
-import warnings
 
 class SharedBackendConf(SharedBackendConfUtils):
 
@@ -312,6 +311,7 @@ class SharedBackendConf(SharedBackendConfUtils):
         return self.ignoreSparkPublicDNS()
 
     def ignoreSparkPublicDNS(self):
+        warnings.warn("Method 'ignoreSparkPublicDNS' is deprecated. It will be removed in the release 3.30 without replacement.")
         return self._jconf.ignoreSparkPublicDNS()
 
     def client_web_enabled(self):
@@ -799,6 +799,7 @@ class SharedBackendConf(SharedBackendConfUtils):
         return self.setIgnoreSparkPublicDNSEnabled()
 
     def setIgnoreSparkPublicDNSEnabled(self):
+        warnings.warn("Method 'etIgnoreSparkPublicDNSEnabled' is deprecated. It will be removed in the release 3.30 without replacement.")
         self._jconf.setIgnoreSparkPublicDNSEnabled()
         return self
 
@@ -807,6 +808,7 @@ class SharedBackendConf(SharedBackendConfUtils):
         return self.setIgnoreSparkPublicDNSDisabled()
 
     def setIgnoreSparkPublicDNSDisabled(self):
+        warnings.warn("Method 'setIgnoreSparkPublicDNSDisabled' is deprecated. It will be removed in the release 3.30 without replacement.")
         self._jconf.setIgnoreSparkPublicDNSDisabled()
         return self
 
